softools
mkttydata xgterm,xterm,vt640,vt240 dev$graphcap cacheg.dat
mkttydata xgterm,xterm,vt640,vt100,vt240,text dev$termcap cachet.dat
mkhelpdb helpdir=lib$root.hd helpdb=lib$helpdb.mip
mkhelpdb helpdir=noao$lib/root.hd helpdb=noao$lib/helpdb.mip
logout
